@@ -17,7 +17,7 @@ class ScratchPadInterpreterPage(InterpreterPage):
         self.scratch.fill((255, 255, 255))
 
         self.interpreter = MyInterpreter({'scratch': self.scratch,
-            'pygame': pygame})
+            'pygame': pygame}, self.renderOutputLine)
 
     def render(self, screen, deltat):
         InterpreterPage.render(self, screen, deltat)
